@@ -2,6 +2,8 @@ register_class("data.table")
 
 # to ---------------------------------------------------------------------------
 
+#' Convert to Class
+#' @noRd
 ts_data.table_dts <- function(x) {
   dts_rm(x)[]
 }
@@ -21,8 +23,10 @@ ts_dts.data.table <- function(x) {
 #' @name ts_ts
 #' @export
 ts_data.table <- function(x) {
-  stopifnot(ts_boxable(x))
-  if (relevant_class(x) == "data.table") return(x)
+  check_ts_boxable(x)
+  if (relevant_class(x) == "data.table") {
+    return(x)
+  }
   ts_data.table_dts(ts_dts(x))
 }
 
