@@ -2,16 +2,18 @@ register_class("tsibble", "tbl_ts")
 
 # to ---------------------------------------------------------------------------
 
+#' Convert to Class
+#' @noRd
 ts_tsibble_dts <- function(x) {
   stopifnot(requireNamespace("tsibble"))
   cid <- dts_cname(x)$id
   ctime <- dts_cname(x)$time
   x <- dts_rm(x)
 
-  if (length(cid) > 0){
-    z <- tsibble::as_tsibble(x, key = !! cid, index = !! ctime)
+  if (length(cid) > 0) {
+    z <- tsibble::as_tsibble(x, key = !!cid, index = !!ctime)
   } else {
-    z <- tsibble::as_tsibble(x, index = !! ctime)
+    z <- tsibble::as_tsibble(x, index = !!ctime)
   }
   z
 }
@@ -37,12 +39,12 @@ ts_dts.tbl_ts <- function(x) {
     z$time <- as.Date(z$time)
   }
 
-  # Ignoring non-numeric measure vars
+  # Ignoring non-numeric measure columns
   is.non.num <- vapply(z[, measures, with = FALSE], is.numeric, TRUE)
   measures.non.num <- measures[!is.non.num]
   if (length(measures.non.num) > 0) {
     message(
-      "Ignoring non-numeric measure vars (",
+      "ignoring non-numeric measure vars (",
       paste(measures.non.num, collapse = ", "),
       ")."
     )
@@ -63,7 +65,8 @@ ts_dts.tbl_ts <- function(x) {
   if (length(cvalue) > 1) {
     # also works if 'cid' includes 'id'
     z <- melt(
-      z, id.vars = c(cid, "time"), measure.vars = cvalue, variable.name = "id"
+      z,
+      id.vars = c(cid, "time"), measure.vars = cvalue, variable.name = "id"
     )
     cvalue <- "value"
   }
@@ -71,7 +74,6 @@ ts_dts.tbl_ts <- function(x) {
   setcolorder(z, c(setdiff(names(z), c("time", cvalue)), "time", cvalue))
   setnames(z, "time", ctime)
   ts_dts(z)
-
 }
 
 
@@ -81,7 +83,9 @@ ts_dts.tbl_ts <- function(x) {
 #' @name ts_ts
 #' @export
 ts_tsibble <- function(x) {
-  stopifnot(ts_boxable(x))
-  if (relevant_class(x) == "tsibble") return(x)
+  check_ts_boxable(x)
+  if (relevant_class(x) == "tsibble") {
+    return(x)
+  }
   ts_tsibble_dts(ts_dts(x))
 }
