@@ -1,10 +1,9 @@
 
 library(testthat)
 library(tsbox)
-
+library(dplyr)
 
 test_that("ts_summary works with irregular series", {
-
   skip_on_cran()
   x <- ts_c(
     mdeaths,
@@ -18,21 +17,18 @@ test_that("ts_summary works with irregular series", {
   )
   smry <- ts_summary(x)
   expect_true(is.na(smry[2, 3]))
-
 })
 
 
 test_that("ts_summary works with single series", {
-
-  expect_is(ts_summary(AirPassengers), "data.frame")
-  expect_is(ts_summary(AirPassengers, spark = TRUE), "data.frame")
-
+  expect_s3_class(ts_summary(AirPassengers), "data.frame")
+  expect_s3_class(ts_summary(AirPassengers, spark = TRUE), "data.frame")
 })
 
 
 test_that("ts_summary works with single observations", {
-  expect_is(ts_summary(ts_span(mdeaths, -1)), "data.frame")
-  expect_is(ts_summary(ts_span(mdeaths, -1), spark = TRUE), "data.frame")
+  expect_s3_class(ts_summary(ts_span(mdeaths, -1)), "data.frame")
+  expect_s3_class(ts_summary(ts_span(mdeaths, -1), spark = TRUE), "data.frame")
 })
 
 test_that("ts_summary works with irregular observations", {
@@ -41,10 +37,8 @@ test_that("ts_summary works with irregular observations", {
     "1988-01-01", 1,
     "2015-11-01", 2
   ) %>%
-  mutate(time = as.Date(time))
+    mutate(time = as.Date(time))
 
-  expect_is(ts_summary(series_irreg), "data.frame")
-  expect_is(ts_summary(series_irreg, spark = TRUE), "data.frame")
+  expect_s3_class(ts_summary(series_irreg), "data.frame")
+  expect_s3_class(ts_summary(series_irreg, spark = TRUE), "data.frame")
 })
-
-
